import {Component, inject, Input, OnInit} from "@angular/core";
import {CdkDrag, CdkDragEnd, CdkDragHandle} from '@angular/cdk/drag-drop';
import {
  MatSnackBar,
  MatSnackBarAction,
  MatSnackBarActions,
  MatSnackBarLabel,
  MatSnackBarRef
} from "@angular/material/snack-bar";
import {MatButtonModule} from "@angular/material/button";
import {PlaylistDisplayInfoDto} from "../typescript-generator/spotifymixerapi";
import {HttpClient, HttpHeaders} from "@angular/common/http";
import {environment} from "../../environment/environment";

@Component({
  selector: 'track-display',
  standalone: true,
  imports: [CdkDrag, CdkDragHandle],
  template: `
    <div class="track-display-item" style="margin: 5px;" cdkDragLockAxis="x" cdkDrag (cdkDragEnded)="dragEnded($event, id)">
      <img src="{{ img }}"class="track-display-element-image" loading="lazy" style="margin:auto">
      <span class="display-text track-display-element " cdkDragHandle>{{ title }}</span>
      <span class="display-text track-display-element ">{{ duration }}</span>
    </div>
  `
})
export class TrackdisplayComponent  {
  durationInSeconds = 1.5;
  _http: HttpClient;

  constructor(private http: HttpClient) {
    this._http = http;
  }



  @Input() order: any | undefined;
  @Input() img: any | undefined;
  @Input() title: any | undefined;
  @Input() duration: any | undefined;
  @Input() id: any | undefined;
  private _snackBar = inject(MatSnackBar);
  public dragEnded(event: CdkDragEnd, id:any): void {
      if(50 <(event.distance.x*-1)){
        this._http.post("http://"+environment.backend_url+":15532/queue",null, {
          headers: new HttpHeaders().set('encryptedSpotifyId', sessionStorage.getItem('spotifyId') || 'invalidToken')
            .set('encryptedSessionId', sessionStorage.getItem('encryptedSessionKey') || 'invalidToken')
            .set('withCredentials', 'true')
            .set('trackId', id)
        }).subscribe(
          (response) => {
            this.openSnackBar()
          },
          (error) => {
            console.error(error);
          }
        );
      }

    event.source._dragRef.reset();
  }

  openSnackBar() {
    this._snackBar.openFromComponent(AddedToQueueSnackBarComponent, {
      duration: this.durationInSeconds * 1000,
    });
  }

}


@Component({
  selector: 'snack-bar-annotated-component-example-snack',
  template: `
        <div style="top: 100px"><span>Added to queue</span></div>
  `,
  styles: `
    :host {
      display: flex;
    }


  `,
  standalone: true,
  imports: [MatButtonModule, MatSnackBarLabel, MatSnackBarActions, MatSnackBarAction],
})
export class AddedToQueueSnackBarComponent {
  snackBarRef = inject(MatSnackBarRef);
}
