import {CommonModule} from "@angular/common";
import {HttpClient, HttpClientModule, HttpHeaders} from "@angular/common/http";
import {Component, inject} from "@angular/core";
import {ActivatedRoute, Router, RouterLink, RouterLinkActive, RouterOutlet} from "@angular/router";
import {
  PlaylistDisplayInfoDto,
  Redis_Spotify_Playlist,
} from "../typescript-generator/spotifymixerapi";
import {SecurityService} from "../encryption/security.service";
import axios from "axios";
import {Subscription} from "rxjs"
import {MatButtonModule} from "@angular/material/button";
import {MatInputModule} from "@angular/material/input";
import {MatFormFieldModule} from "@angular/material/form-field";
import {MatExpansionModule} from "@angular/material/expansion";
import {MatDatepickerModule} from "@angular/material/datepicker";
import {TrackdisplayComponent} from "../Track/trackdisplay.component";
import {FooterMenuComponent} from "../menu/menu.component";
import {MatBottomSheet} from "@angular/material/bottom-sheet";
import {environment} from "../../environment/environment";

@Component({

  standalone: true,
  imports: [CommonModule,
    RouterOutlet,
    RouterLink,
    RouterLinkActive,
    HttpClientModule,MatButtonModule,
    MatExpansionModule,
    MatFormFieldModule,
    MatInputModule,
    MatDatepickerModule,
    TrackdisplayComponent,FooterMenuComponent
  ],
  providers: [],
  template: `
    <div>
      <ul [ngStyle]="opened_index !='undefined' ? {padding: '50px 0 50px 0'} : {}">
        @for (playlist of playlists; track playlist; let  i = $index) {
          <li style="margin: 10px;">
            <div display='block'>
              <mat-expansion-panel [ngStyle]="opened_index!=i && opened_index!='undefined' ? {display: 'none'} : {}"   class="playlist-expension-panel" >
                <mat-expansion-panel-header class="playlist-expension-panel-header" (click)="headerToogle(i)" >

                  <mat-panel-title class="display-text line-height-one "> <img src="{{playlist.icon}}" class="playlist-display-element-image">
                    <span class="margin-auto">{{playlist.name}}</span>
                  </mat-panel-title>

                </mat-expansion-panel-header>
                <li *ngFor="let item of playlist.trackDisplayInfoDtoList; let j = index" [attr.data-index]="j" >
                  <track-display [order]="j" [img]="item.image" [title]="item.name" [duration]="item.duration" [id]="item.id" ></track-display>
                </li>
              </mat-expansion-panel>
            </div>
        }

      </ul>
    </div>


    <footer>
      <footer-menu></footer-menu>
    </footer>


  `
})
export class PlaylistComponent {
  isLoading: boolean;
  isDataLoaded$: Subscription | undefined;
  _http: HttpClient;
  playlists:PlaylistDisplayInfoDto[] | undefined;
  opened_index: any = 'undefined';

  constructor(private http: HttpClient, router: Router, route: ActivatedRoute, securityService: SecurityService) {
     this.isLoading = true;
    this._http = http;
  }

  headerToogle(i:number){
    if(this.opened_index == 'undefined'){
      this.opened_index = i;
    }else{
      this.opened_index = 'undefined';
    }
    console.log("headerToogle:" + this.opened_index);
  }

  ngOnInit() {
    this.isDataLoaded$ = this._http.get<PlaylistDisplayInfoDto[]>("http://"+environment.backend_url+":15532/playlists", {
      headers: new HttpHeaders().set('spotifyId', sessionStorage.getItem('spotifyId') || 'invalidToken')
        .set('withCredentials', 'true')
    }).subscribe(
      (response) => {
        this.playlists=response;
        console.log(this.playlists);
      },
      (error) => {
        console.error(error);
      }
    );
  }


}
