import {CommonModule} from "@angular/common";
import {HttpClient, HttpClientModule, HttpHeaders} from "@angular/common/http";
import {Component, inject} from "@angular/core";
import {ActivatedRoute, Router, RouterLink, RouterLinkActive, RouterOutlet} from "@angular/router";
import {
  PlaylistDisplayInfoDto,
  Redis_Spotify_Playlist,
} from "../typescript-generator/spotifymixerapi";
import {SecurityService} from "../encryption/security.service";
import axios from "axios";
import {Subscription} from "rxjs"
import {MatButtonModule} from "@angular/material/button";
import {MatInputModule} from "@angular/material/input";
import {MatFormFieldModule} from "@angular/material/form-field";
import {MatExpansionModule} from "@angular/material/expansion";
import {MatDatepickerModule} from "@angular/material/datepicker";
import {TrackdisplayComponent} from "../Track/trackdisplay.component";
import {FooterMenuComponent} from "../menu/menu.component";
import {MatBottomSheet} from "@angular/material/bottom-sheet";
import {environment} from "../../environment/environment";

@Component({

  standalone: true,
  imports: [CommonModule,
    RouterOutlet,
    RouterLink,
    RouterLinkActive,
    HttpClientModule,MatButtonModule,
    MatExpansionModule,
    MatFormFieldModule,
    MatInputModule,
    MatDatepickerModule,
    TrackdisplayComponent,FooterMenuComponent
  ],
  providers: [],
  template: `

    <div  *ngFor="let item of playlists?.trackDisplayInfoDtoList; let j = index" [attr.data-index]="j">
      <track-display [order]="j" [img]="item.image" [title]="item.name" [duration]="item.duration" ></track-display>
    </div>


    <footer>
      <footer-menu></footer-menu>
    </footer>


  `
})
export class QueueComponent {
  _http: HttpClient;
  playlists:PlaylistDisplayInfoDto| undefined;

  constructor(private http: HttpClient, router: Router, route: ActivatedRoute, securityService: SecurityService) {
    this._http = http;
  }


  ngOnInit() {
     this._http.get<PlaylistDisplayInfoDto>("http://"+environment.backend_url+":15532/queue", {
      headers: new HttpHeaders().set('encryptedSpotifyId', sessionStorage.getItem('spotifyId') || 'invalidToken')
        .set('withCredentials', 'true')
    }).subscribe(
      (response) => {
        this.playlists=response;
        console.log(this.playlists);
      },
      (error) => {
        console.error(error);
      }
    );
  }


}
