import {CommonModule} from "@angular/common";
import {HttpClient, HttpClientModule, HttpErrorResponse, HttpHeaders} from "@angular/common/http";
import {Component} from "@angular/core";
import {ActivatedRoute, Router, RouterLink, RouterLinkActive, RouterOutlet} from "@angular/router";
import {
  DisplayNameAndImage,
  PlaylistDisplayInfoDto,
  SessionDataMainPageResponse, Spotify_DeviceObject, TrackDisplayInfoDto
} from "../typescript-generator/spotifymixerapi";
import {SecurityService} from "../encryption/security.service";
import {MatProgressSpinnerModule} from '@angular/material/progress-spinner';
import {catchError, interval, map, Observable, ObservableInput, Subscription, switchMap} from "rxjs"
import {MatBottomSheetModule} from "@angular/material/bottom-sheet";
import {TrackdisplayComponent} from "../Track/trackdisplay.component";
import {MatDividerModule} from "@angular/material/divider";
import {TrackListComponent} from "../Track/track.list.component";
import {FooterMenuComponent} from "../menu/menu.component";
import {NgxAudioPlayerModule, Track} from 'ngx-audio-player';
import {MatInputModule} from "@angular/material/input";
import {MatSelectModule} from "@angular/material/select";
import {MatFormFieldModule} from "@angular/material/form-field";
import {FormsModule, ReactiveFormsModule} from "@angular/forms";
import {MatCheckboxModule} from "@angular/material/checkbox";
import {MusicPlayerComponent} from "../player/music.player.component";
import {MatIconModule} from '@angular/material/icon';
import { environment } from "../../environment/environment";

@Component({
  standalone: true,
  imports: [CommonModule,
    RouterOutlet,
    RouterLink,
    RouterLinkActive,
    HttpClientModule,
    MatProgressSpinnerModule,
    MatBottomSheetModule,
    TrackdisplayComponent,
    MatDividerModule,
    TrackListComponent, FooterMenuComponent,NgxAudioPlayerModule,
    MatCheckboxModule,
    FormsModule,
    ReactiveFormsModule,
    MatFormFieldModule,
    MatSelectModule,
    MatInputModule,
    MusicPlayerComponent,
    MatIconModule
  ],
  providers: [],
  template: `

    <div>
      <music-player [trackDisplayInfoDto]="currentlyPlayedSong"></music-player>
    </div>

    <div class="spotify-device-select-div">
      <mat-form-field class="spotify-device-select">
        <mat-label>Choose an option</mat-label>
        <mat-select (selectionChange)="doSomething($event)" [(value)]="currentlySelectedDeviceName">
          <div *ngFor="let userDevice of userDevices; let j = index" [attr.data-index]="j">
            <mat-option [value]="userDevice.name">{{ userDevice.name }}</mat-option>
          </div>

        </mat-select>
      </mat-form-field>
    </div>

    <div *ngFor="let item of sessionQueue?.trackDisplayInfoDtoList; let j = index" [attr.data-index]="j">
      <track-display [order]="j" [img]="item.image" [title]="item.name" [duration]="item.duration"></track-display>
    </div>


    <footer>
      <footer-menu></footer-menu>
    </footer>

  `
})
export class SessionCopmonent {
  isLoading: boolean;
  sessionName: string | undefined;
  userDevices: Spotify_DeviceObject[] | undefined;
  displayNamesAndImages: DisplayNameAndImage[] | undefined;
  isDataLoaded$: Subscription | undefined;
  _http: HttpClient;
  sessionQueueObservable$ : Observable<PlaylistDisplayInfoDto> | undefined;
  sessionQueue: PlaylistDisplayInfoDto | undefined;
  currentlyPlayedSong: TrackDisplayInfoDto | undefined;
  currentlySelectedDeviceName:  String | undefined;

  doSomething(event : any){
    console.log(event)
    this._http.post("http://"+environment.backend_url+":15532/session/device",null, {
      headers: new HttpHeaders().set('encryptedSessionKey', sessionStorage.getItem('encryptedSessionKey') || 'invalidToken')
        .set('deviceName',event.value)
        .set('withCredentials', 'true')
    }).subscribe(
      (response) => {
      },
      (error) => {
        console.error(error);
      }
    );
  }


  constructor(private http: HttpClient, router: Router, route: ActivatedRoute, securityService: SecurityService) {
     this.isLoading = true;
    this._http = http;
  }

  ngOnInit() {
    this.isDataLoaded$ = this._http.get<SessionDataMainPageResponse>("http://"+environment.backend_url+":15532/session/getdata", {
      headers: new HttpHeaders().set('encryptedSessionKey', sessionStorage.getItem('encryptedSessionKey') || 'invalidToken')
        .set('withCredentials', 'true')
    }).subscribe(
      (response) => {
        console.log(response);
        this.sessionName = response.sessionName
        this.displayNamesAndImages = response.users
        this.userDevices = response.devices
        this.currentlySelectedDeviceName = response.currentlySelectedDevice.name
      },
      (error) => {
        console.error(error);
      }
    );

    const autoRefreshRateInMilliSeconds = 5000; //5 seconds
    this.sessionQueueObservable$ =interval(autoRefreshRateInMilliSeconds).pipe(
      switchMap(()=> this.getSessionQueue())
    );
  }

/*this._http.get<PlaylistDisplayInfoDto>("http://"+environment.backend_url+":15532/queue/session", {
      headers: new HttpHeaders().set('encryptedSessionKey', sessionStorage.getItem('encryptedSessionKey') || 'invalidToken')
        .set('withCredentials', 'true')
    }).subscribe(
      (response) => {
        this.sessionQueue=response;
        this.currentlyPlayedSong = response.trackDisplayInfoDtoList.at(0)
        console.log(this.sessionQueue);
      },
      (error) => {
        console.error(error);
      }
    );*/
  getSessionQueue() :Observable<PlaylistDisplayInfoDto> {
      return this._http.get<PlaylistDisplayInfoDto>("http://"+environment.backend_url+":15532/queue/session", {
        headers: new HttpHeaders().set('encryptedSessionKey', sessionStorage.getItem('encryptedSessionKey') || 'invalidToken')
          .set('withCredentials', 'true')
      }).pipe(
        map<any,PlaylistDisplayInfoDto>((response: PlaylistDisplayInfoDto) =>{
          this.sessionQueue=response;
          this.currentlyPlayedSong = response.trackDisplayInfoDtoList.at(0)
          console.log(this.sessionQueue);
          return response
        })
      )
  }


}
